aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio
diff options
context:
space:
mode:
authorRoy Ben Shabat <Roy.mail.net@gmail.com>2019-12-21 22:39:08 +0200
committerRoy Ben Shabat <Roy.mail.net@gmail.com>2019-12-21 22:39:08 +0200
commitaeb55d27a8abf291913724fc1676ecbf27cb2c1a (patch)
tree007b0287c23b75883750a786cb2601afbf7f5d81 /Software/Visual_Studio
parent582c05b00aa1d0fd9086b4a245dcc987eee9fc39 (diff)
downloadTango-aeb55d27a8abf291913724fc1676ecbf27cb2c1a.tar.gz
Tango-aeb55d27a8abf291913724fc1676ecbf27cb2c1a.zip
Refactored Site Rmls & Catalogs to FK.
Implemented Sites & Site Builders. Implemented DTO's and ActionLogs. Changed SQLExaminer scripts accordingly.
Diffstat (limited to 'Software/Visual_Studio')
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Sites/ViewModels/MainViewVM.cs1
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Sites/ViewModels/SiteDetailsViewVM.cs50
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Sites/Views/SiteDetailsView.xaml2
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Jobs/ViewModels/JobViewVM.cs2
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.Jobs/ViewModels/JobsViewVM.cs4
-rw-r--r--Software/Visual_Studio/PPC/Modules/Tango.PPC.MachineSettings/ViewModels/MainViewVM.cs2
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.UI/ViewModels/MainViewVM.cs6
-rw-r--r--Software/Visual_Studio/Tango.BL/Builders/CatalogsCollectionBuilder.cs4
-rw-r--r--Software/Visual_Studio/Tango.BL/Builders/RmlsCollectionBuilder.cs2
-rw-r--r--Software/Visual_Studio/Tango.BL/Builders/SiteBuilder.cs58
-rw-r--r--Software/Visual_Studio/Tango.BL/Builders/SitesCollectionBuilder.cs42
-rw-r--r--Software/Visual_Studio/Tango.BL/DTO/SiteDTO.cs18
-rw-r--r--Software/Visual_Studio/Tango.BL/DTO/SitesCatalogDTO.cs7
-rw-r--r--Software/Visual_Studio/Tango.BL/DTO/SitesCatalogDTOBase.cs4
-rw-r--r--Software/Visual_Studio/Tango.BL/DTO/SitesRmlDTO.cs5
-rw-r--r--Software/Visual_Studio/Tango.BL/Entities/ColorCatalogBase.cs38
-rw-r--r--Software/Visual_Studio/Tango.BL/Entities/HardwareBlowerBase.cs4
-rw-r--r--Software/Visual_Studio/Tango.BL/Entities/OrganizationBase.cs38
-rw-r--r--Software/Visual_Studio/Tango.BL/Entities/RmlBase.cs38
-rw-r--r--Software/Visual_Studio/Tango.BL/Entities/SiteBase.cs121
-rw-r--r--Software/Visual_Studio/Tango.BL/Entities/SitesCatalogBase.cs102
-rw-r--r--Software/Visual_Studio/Tango.BL/Entities/SitesRmlBase.cs88
-rw-r--r--Software/Visual_Studio/Tango.BL/Tango.BL.csproj4
-rw-r--r--Software/Visual_Studio/Tango.DAL.Remote/DB/COLOR_CATALOGS.cs3
-rw-r--r--Software/Visual_Studio/Tango.DAL.Remote/DB/ORGANIZATION.cs3
-rw-r--r--Software/Visual_Studio/Tango.DAL.Remote/DB/RML.cs3
-rw-r--r--Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.Designer.cs2
-rw-r--r--Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx192
-rw-r--r--Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx.diagram161
-rw-r--r--Software/Visual_Studio/Tango.DAL.Remote/DB/SITE.cs13
-rw-r--r--Software/Visual_Studio/Tango.DAL.Remote/DB/SITES_CATALOGS.cs5
-rw-r--r--Software/Visual_Studio/Tango.DAL.Remote/DB/SITES_RMLS.cs3
-rw-r--r--Software/Visual_Studio/Tango.SQLExaminer/SQLExaminer/Configurations/ProvisionMachine.xmlbin87410 -> 87446 bytes
-rw-r--r--Software/Visual_Studio/Tango.SQLExaminer/SQLExaminer/Configurations/UpdateMachine.xmlbin54676 -> 54712 bytes
34 files changed, 874 insertions, 151 deletions
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Sites/ViewModels/MainViewVM.cs b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Sites/ViewModels/MainViewVM.cs
index bcbcb6d16..5db5e004d 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Sites/ViewModels/MainViewVM.cs
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Sites/ViewModels/MainViewVM.cs
@@ -6,6 +6,7 @@ using System.Text;
using System.Threading.Tasks;
using Tango.BL;
using Tango.BL.ActionLogs;
+using Tango.BL.Builders;
using Tango.BL.Entities;
using Tango.Core.Commands;
using Tango.Core.Threading;
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Sites/ViewModels/SiteDetailsViewVM.cs b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Sites/ViewModels/SiteDetailsViewVM.cs
index 73d4c49cb..92dd8273d 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Sites/ViewModels/SiteDetailsViewVM.cs
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Sites/ViewModels/SiteDetailsViewVM.cs
@@ -13,6 +13,7 @@ using Tango.MachineStudio.Common.Notifications;
using Tango.MachineStudio.Common.Authentication;
using Tango.BL.ActionLogs;
using Tango.BL.DTO;
+using Tango.BL.Builders;
namespace Tango.MachineStudio.Sites.ViewModels
{
@@ -41,13 +42,6 @@ namespace Tango.MachineStudio.Sites.ViewModels
set { _organizations = value; RaisePropertyChangedAuto(); }
}
- private Organization _selectedOrganization;
- public Organization SelectedOrganization
- {
- get { return _selectedOrganization; }
- set { _selectedOrganization = value; RaisePropertyChangedAuto(); }
- }
-
private SelectedObjectCollection<Rml> _rmls;
public SelectedObjectCollection<Rml> Rmls
{
@@ -97,31 +91,30 @@ namespace Tango.MachineStudio.Sites.ViewModels
else
{
_isNew = false;
- Site = await _db.Sites.SingleOrDefaultAsync(x => x.Guid == siteGuid);
+ Site = await new SiteBuilder(_db).Set(siteGuid)
+ .WithSiteCatalogs()
+ .WithCatalogs()
+ .WithSiteRmls()
+ .WithRmls()
+ .WithOrganization()
+ .BuildAsync();
}
Machines = await _db.Machines.Where(x => x.SiteGuid == Site.Guid).Include(x => x.Organization).ToListAsync();
- var site_rmls = await _db.SitesRmls.Where(x => x.SiteGuid == Site.Guid).ToListAsync();
- var site_catalogs = await _db.SitesCatalogs.Where(x => x.SiteGuid == Site.Guid).ToListAsync();
-
var rmls = await _db.Rmls.OrderBy(x => x.Name).ToListAsync();
var catalogs = await _db.ColorCatalogs.OrderBy(x => x.Name).ToListAsync();
- Rmls = new SelectedObjectCollection<Rml>(rmls.ToObservableCollection(), rmls.Where(rml => site_rmls.Exists(siteRml => siteRml.RmlGuid == rml.Guid)).ToObservableCollection());
- Catalogs = new SelectedObjectCollection<ColorCatalog>(catalogs.ToObservableCollection(), catalogs.Where(catalog => site_catalogs.Exists(siteCatalog => siteCatalog.CatalogGuid == catalog.Guid)).ToObservableCollection());
-
- SelectedOrganization = Organizations.SingleOrDefault(x => x.Guid == Site.OrganizationGuid);
+ Rmls = new SelectedObjectCollection<Rml>(rmls.ToObservableCollection(), Site.SitesRmls.Select(x => x.Rml).ToObservableCollection());
+ Catalogs = new SelectedObjectCollection<ColorCatalog>(catalogs.ToObservableCollection(), Site.SitesCatalogs.Select(x => x.ColorCatalog).ToObservableCollection());
- _siteBeforeSave = SiteDTO.FromObservable(Site, site_rmls, site_catalogs, SelectedOrganization.Name);
+ _siteBeforeSave = SiteDTO.FromObservable(Site);
}
private async void Save()
{
try
{
- Site.OrganizationGuid = SelectedOrganization?.Guid;
-
if (!Site.Validate(_db))
{
_notification.ShowError(String.Join("\n", Site.ValidationErrors));
@@ -132,38 +125,29 @@ namespace Tango.MachineStudio.Sites.ViewModels
using (_notification.PushTaskItem("Saving site details..."))
{
- var site_rmls = await _db.SitesRmls.Where(x => x.SiteGuid == Site.Guid).ToListAsync();
- var site_catalogs = await _db.SitesCatalogs.Where(x => x.SiteGuid == Site.Guid).ToListAsync();
-
- //_db.SitesRmls.RemoveRange(site_rmls);
- //_db.SitesCatalogs.RemoveRange(site_catalogs);
-
//Remove site rmls.
- site_rmls.ToList().Where(x => !Rmls.SynchedSource.ToList().Exists(y => y.Guid == x.RmlGuid)).ToList().ForEach(x => _db.SitesRmls.Remove(x));
- site_catalogs.ToList().Where(x => !Catalogs.SynchedSource.ToList().Exists(y => y.Guid == x.CatalogGuid)).ToList().ForEach(x => _db.SitesCatalogs.Remove(x));
+ Site.SitesRmls.ToList().Where(x => !Rmls.SynchedSource.ToList().Exists(y => y.Guid == x.RmlGuid)).ToList().ForEach(x => _db.SitesRmls.Remove(x));
+ Site.SitesCatalogs.ToList().Where(x => !Catalogs.SynchedSource.ToList().Exists(y => y.Guid == x.ColorCatalogGuid)).ToList().ForEach(x => _db.SitesCatalogs.Remove(x));
- foreach (var selectedRml in Rmls.SynchedSource.Where(x => !site_rmls.Exists(y => y.RmlGuid == x.Guid)))
+ foreach (var selectedRml in Rmls.SynchedSource.Where(x => !Site.SitesRmls.ToList().Exists(y => y.RmlGuid == x.Guid)))
{
_db.SitesRmls.Add(new SitesRml() { SiteGuid = Site.Guid, RmlGuid = selectedRml.Guid });
}
- foreach (var selectedCatalog in Catalogs.SynchedSource.Where(x => !site_catalogs.Exists(y => y.CatalogGuid == x.Guid)))
+ foreach (var selectedCatalog in Catalogs.SynchedSource.Where(x => !Site.SitesCatalogs.ToList().Exists(y => y.ColorCatalogGuid == x.Guid)))
{
- _db.SitesCatalogs.Add(new SitesCatalog() { SiteGuid = Site.Guid, CatalogGuid = selectedCatalog.Guid });
+ _db.SitesCatalogs.Add(new SitesCatalog() { SiteGuid = Site.Guid, ColorCatalogGuid = selectedCatalog.Guid });
}
await _db.SaveChangesAsync();
- var final_site_rmls = _db.SitesRmls.ToList();
- var final_site_catalogs = _db.SitesCatalogs.ToList();
-
if (_isNew)
{
_actionLogManager.InsertLog(BL.Enumerations.ActionLogType.SiteCreated, _authentication.CurrentUser, Site.Name, Site, "Site created using Machine Studio.");
}
else
{
- SiteDTO siteAfter = SiteDTO.FromObservable(Site, final_site_rmls, final_site_catalogs, SelectedOrganization.Name);
+ SiteDTO siteAfter = SiteDTO.FromObservable(Site);
_actionLogManager.InsertLog(BL.Enumerations.ActionLogType.SiteSaved, _authentication.CurrentUser, _siteBeforeSave.Name, _siteBeforeSave, siteAfter, "Site saved using Machine Studio.");
_siteBeforeSave = siteAfter;
}
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Sites/Views/SiteDetailsView.xaml b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Sites/Views/SiteDetailsView.xaml
index b3496a5e2..182f05be0 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Sites/Views/SiteDetailsView.xaml
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Sites/Views/SiteDetailsView.xaml
@@ -84,7 +84,7 @@
<TextBox Text="{Binding Site.Name,UpdateSourceTrigger=PropertyChanged,ValidatesOnDataErrors=True,ValidatesOnNotifyDataErrors=True}"></TextBox>
<TextBlock Text="Organization:" ></TextBlock>
- <ComboBox ItemsSource="{Binding Organizations}" SelectedItem="{Binding SelectedOrganization}" DisplayMemberPath="Name"></ComboBox>
+ <ComboBox ItemsSource="{Binding Organizations}" SelectedItem="{Binding Site.Organization}" DisplayMemberPath="Name"></ComboBox>
<TextBlock Text="Description:" ></TextBlock>
<TextBox Text="{Binding Site.Description,UpdateSourceTrigger=PropertyChanged,ValidatesOnDataErrors=True,ValidatesOnNotifyDataErrors=True}"></TextBox>
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Jobs/ViewModels/JobViewVM.cs b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Jobs/ViewModels/JobViewVM.cs
index 0175b949e..1b80eed35 100644
--- a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Jobs/ViewModels/JobViewVM.cs
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Jobs/ViewModels/JobViewVM.cs
@@ -468,7 +468,7 @@ namespace Tango.PPC.Jobs.ViewModels
Job.ValidateOnPropertyChanged = true;
LogManager.Log("Loading RMLS...");
- Rmls = (await new RmlsCollectionBuilder(_db).SetAll().WithActiveParametersGroup().WithCAT(Job.MachineGuid).WithCCT().WithLiquidFactors().WithSite(MachineProvider.Machine.SiteGuid).BuildAsync()).ToList();
+ Rmls = (await new RmlsCollectionBuilder(_db).SetAll().WithActiveParametersGroup().WithCAT(Job.MachineGuid).WithCCT().WithLiquidFactors().ForSite(MachineProvider.Machine.SiteGuid).BuildAsync()).ToList();
LogManager.Log("Loading Color Spaces...");
ColorSpaces = await _db.ColorSpaces.ToListAsync();
LogManager.Log("Loading Spool Types...");
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Jobs/ViewModels/JobsViewVM.cs b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Jobs/ViewModels/JobsViewVM.cs
index 109e3e27a..fb3818e41 100644
--- a/Software/Visual_Studio/PPC/Modules/Tango.PPC.Jobs/ViewModels/JobsViewVM.cs
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.Jobs/ViewModels/JobsViewVM.cs
@@ -736,8 +736,8 @@ namespace Tango.PPC.Jobs.ViewModels
//Load catalogs.
using (ObservablesContext db = ObservablesContext.CreateDefault())
{
- _catalogs = await new CatalogsCollectionBuilder(db).SetAll().WithSite(MachineProvider.Machine.SiteGuid).BuildAsync();
- _rmls = await new RmlsCollectionBuilder(db).SetAll().WithSite(MachineProvider.Machine.SiteGuid).BuildAsync();
+ _catalogs = await new CatalogsCollectionBuilder(db).SetAll().ForSite(MachineProvider.Machine.SiteGuid).BuildAsync();
+ _rmls = await new RmlsCollectionBuilder(db).SetAll().ForSite(MachineProvider.Machine.SiteGuid).BuildAsync();
}
MachineDataSynchronizer.SynchronizationEnded += MachineDataSynchronizer_SynchronizationEnded;
diff --git a/Software/Visual_Studio/PPC/Modules/Tango.PPC.MachineSettings/ViewModels/MainViewVM.cs b/Software/Visual_Studio/PPC/Modules/Tango.PPC.MachineSettings/ViewModels/MainViewVM.cs
index 5077fd884..8b48c51aa 100644
--- a/Software/Visual_Studio/PPC/Modules/Tango.PPC.MachineSettings/ViewModels/MainViewVM.cs
+++ b/Software/Visual_Studio/PPC/Modules/Tango.PPC.MachineSettings/ViewModels/MainViewVM.cs
@@ -235,7 +235,7 @@ namespace Tango.PPC.MachineSettings.ViewModels
using (ObservablesContext db = ObservablesContext.CreateDefault())
{
- Rmls = await new RmlsCollectionBuilder(db).SetAll().WithSite(MachineProvider.Machine.SiteGuid).BuildAsync();
+ Rmls = await new RmlsCollectionBuilder(db).SetAll().ForSite(MachineProvider.Machine.SiteGuid).BuildAsync();
}
}
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.UI/ViewModels/MainViewVM.cs b/Software/Visual_Studio/PPC/Tango.PPC.UI/ViewModels/MainViewVM.cs
index eeb11ffab..f78a7f334 100644
--- a/Software/Visual_Studio/PPC/Tango.PPC.UI/ViewModels/MainViewVM.cs
+++ b/Software/Visual_Studio/PPC/Tango.PPC.UI/ViewModels/MainViewVM.cs
@@ -118,7 +118,7 @@ namespace Tango.PPC.UI.ViewModels
using (ObservablesContext db = ObservablesContext.CreateDefault())
{
- rmls = await new RmlsCollectionBuilder(db).SetAll().WithSite(MachineProvider.Machine.SiteGuid).BuildListAsync();
+ rmls = await new RmlsCollectionBuilder(db).SetAll().ForSite(MachineProvider.Machine.SiteGuid).BuildListAsync();
}
var selectedRml = rmls.SingleOrDefault(x => x.Guid == Settings.LoadedRmlGuid);
@@ -156,7 +156,7 @@ namespace Tango.PPC.UI.ViewModels
else
{
LogManager.Log("Selected minimal temperature...");
- var rmlsToAvg = new RmlsCollectionBuilder(db).SetAll().WithSite(MachineProvider.Machine.SiteGuid).WithActiveParametersGroup().Build();
+ var rmlsToAvg = new RmlsCollectionBuilder(db).SetAll().ForSite(MachineProvider.Machine.SiteGuid).WithActiveParametersGroup().Build();
processTables = rmlsToAvg.Select(x => x.GetActiveProcessGroup()).SelectMany(x => x.ProcessParametersTables).ToList();
}
@@ -198,7 +198,7 @@ namespace Tango.PPC.UI.ViewModels
using (ObservablesContext db = ObservablesContext.CreateDefault())
{
- rmls = await new RmlsCollectionBuilder(db).SetAll().WithSite(MachineProvider.Machine.SiteGuid).WithActiveParametersGroup().BuildListAsync();
+ rmls = await new RmlsCollectionBuilder(db).SetAll().ForSite(MachineProvider.Machine.SiteGuid).WithActiveParametersGroup().BuildListAsync();
}
var selectedRml = rmls.SingleOrDefault(x => x.Guid == Settings.LoadedRmlGuid);
diff --git a/Software/Visual_Studio/Tango.BL/Builders/CatalogsCollectionBuilder.cs b/Software/Visual_Studio/Tango.BL/Builders/CatalogsCollectionBuilder.cs
index 9b24899c4..fb690eb99 100644
--- a/Software/Visual_Studio/Tango.BL/Builders/CatalogsCollectionBuilder.cs
+++ b/Software/Visual_Studio/Tango.BL/Builders/CatalogsCollectionBuilder.cs
@@ -14,13 +14,13 @@ namespace Tango.BL.Builders
{
}
- public virtual CatalogsCollectionBuilder WithSite(String siteGuid)
+ public virtual CatalogsCollectionBuilder ForSite(String siteGuid)
{
return AddQueryStep(1, (query) =>
{
if (siteGuid != null)
{
- var siteCatalogsGuids = Context.SitesCatalogs.Where(x => x.SiteGuid == siteGuid).ToList().Select(x => x.CatalogGuid).Where(x => x != null).Distinct().ToArray();
+ var siteCatalogsGuids = Context.SitesCatalogs.Where(x => x.SiteGuid == siteGuid).ToList().Select(x => x.ColorCatalogGuid).Where(x => x != null).Distinct().ToArray();
if (siteCatalogsGuids.Length > 0)
{
diff --git a/Software/Visual_Studio/Tango.BL/Builders/RmlsCollectionBuilder.cs b/Software/Visual_Studio/Tango.BL/Builders/RmlsCollectionBuilder.cs
index 9408d714b..b23eb9507 100644
--- a/Software/Visual_Studio/Tango.BL/Builders/RmlsCollectionBuilder.cs
+++ b/Software/Visual_Studio/Tango.BL/Builders/RmlsCollectionBuilder.cs
@@ -14,7 +14,7 @@ namespace Tango.BL.Builders
{
}
- public virtual RmlsCollectionBuilder WithSite(String siteGuid)
+ public virtual RmlsCollectionBuilder ForSite(String siteGuid)
{
return AddQueryStep(1, (query) =>
{
diff --git a/Software/Visual_Studio/Tango.BL/Builders/SiteBuilder.cs b/Software/Visual_Studio/Tango.BL/Builders/SiteBuilder.cs
new file mode 100644
index 000000000..938598fc6
--- /dev/null
+++ b/Software/Visual_Studio/Tango.BL/Builders/SiteBuilder.cs
@@ -0,0 +1,58 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Text;
+using System.Threading.Tasks;
+using System.Data.Entity;
+using Tango.BL.Entities;
+
+namespace Tango.BL.Builders
+{
+ public class SiteBuilder : EntityBuilderBase<Site, SiteBuilder>
+ {
+ public SiteBuilder(ObservablesContext context) : base(context)
+ {
+
+ }
+
+ public virtual SiteBuilder WithSiteCatalogs()
+ {
+ return AddQueryStep(1, (query) =>
+ {
+ return query.Include(x => x.SitesCatalogs);
+ });
+ }
+
+ public virtual SiteBuilder WithCatalogs()
+ {
+ return AddQueryStep(2, (query) =>
+ {
+ return query.Include(x => x.SitesCatalogs.Select(y => y.ColorCatalog));
+ });
+ }
+
+ public virtual SiteBuilder WithSiteRmls()
+ {
+ return AddQueryStep(3, (query) =>
+ {
+ return query.Include(x => x.SitesRmls);
+ });
+ }
+
+ public virtual SiteBuilder WithRmls()
+ {
+ return AddQueryStep(4, (query) =>
+ {
+ return query.Include(x => x.SitesRmls.Select(y => y.Rml));
+ });
+ }
+
+ public virtual SiteBuilder WithOrganization()
+ {
+ return AddQueryStep(5, (query) =>
+ {
+ return query.Include(x => x.Organization);
+ });
+ }
+ }
+}
diff --git a/Software/Visual_Studio/Tango.BL/Builders/SitesCollectionBuilder.cs b/Software/Visual_Studio/Tango.BL/Builders/SitesCollectionBuilder.cs
new file mode 100644
index 000000000..0c80b5a37
--- /dev/null
+++ b/Software/Visual_Studio/Tango.BL/Builders/SitesCollectionBuilder.cs
@@ -0,0 +1,42 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Text;
+using System.Threading.Tasks;
+using Tango.BL.Entities;
+using System.Data.Entity;
+
+namespace Tango.BL.Builders
+{
+ public class SitesCollectionBuilder : EntityCollectionBuilderBase<Site, SitesCollectionBuilder>
+ {
+ public SitesCollectionBuilder(ObservablesContext context) : base(context)
+ {
+
+ }
+
+ public virtual SitesCollectionBuilder WithSiteCatalogs()
+ {
+ return AddQueryStep(1, (query) =>
+ {
+ return query.Include(x => x.SitesCatalogs);
+ });
+ }
+
+ public virtual SitesCollectionBuilder WithSiteRmls()
+ {
+ return AddQueryStep(2, (query) =>
+ {
+ return query.Include(x => x.SitesRmls);
+ });
+ }
+
+ public virtual SitesCollectionBuilder WithOrganization()
+ {
+ return AddQueryStep(3, (query) =>
+ {
+ return query.Include(x => x.Organization);
+ });
+ }
+ }
+}
diff --git a/Software/Visual_Studio/Tango.BL/DTO/SiteDTO.cs b/Software/Visual_Studio/Tango.BL/DTO/SiteDTO.cs
index 2ba9ca693..4d09bda9c 100644
--- a/Software/Visual_Studio/Tango.BL/DTO/SiteDTO.cs
+++ b/Software/Visual_Studio/Tango.BL/DTO/SiteDTO.cs
@@ -10,25 +10,17 @@ namespace Tango.BL.DTO
{
public class SiteDTO : SiteDTOBase
{
- public List<SitesRmlDTO> SiteRmls { get; set; }
+ public List<SitesRmlDTO> SitesRmls { get; set; }
- public List<SitesCatalogDTO> SiteCatalogs { get; set; }
+ public List<SitesCatalogDTO> SitesCatalogs { get; set; }
+ [ObservableDTOProperty(MapsTo = nameof(Site.Organization) + "." + nameof(Site.Organization.Name))]
public String OrganizationName { get; set; }
public SiteDTO()
{
- SiteRmls = new List<SitesRmlDTO>();
- SiteCatalogs = new List<SitesCatalogDTO>();
- }
-
- public static SiteDTO FromObservable(Site observable, IEnumerable<SitesRml> siteRmls, IEnumerable<SitesCatalog> siteCatalogs, String organizationName)
- {
- SiteDTO dto = FromObservable(observable);
- dto.OrganizationName = organizationName;
- dto.SiteRmls = siteRmls.Select(x => SitesRmlDTO.FromObservable(x)).ToList();
- dto.SiteCatalogs = siteCatalogs.Select(x => SitesCatalogDTO.FromObservable(x)).ToList();
- return dto;
+ SitesRmls = new List<SitesRmlDTO>();
+ SitesCatalogs = new List<SitesCatalogDTO>();
}
protected override string OnGetActionLogName()
diff --git a/Software/Visual_Studio/Tango.BL/DTO/SitesCatalogDTO.cs b/Software/Visual_Studio/Tango.BL/DTO/SitesCatalogDTO.cs
index 4e1d44e6d..3c22989d8 100644
--- a/Software/Visual_Studio/Tango.BL/DTO/SitesCatalogDTO.cs
+++ b/Software/Visual_Studio/Tango.BL/DTO/SitesCatalogDTO.cs
@@ -4,11 +4,18 @@ using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
+using Tango.BL.Entities;
namespace Tango.BL.DTO
{
public class SitesCatalogDTO : SitesCatalogDTOBase
{
+ [ObservableDTOProperty(MapsTo = nameof(SitesCatalog.ColorCatalog) + "." + nameof(SitesCatalog.ColorCatalog.Name))]
+ public String CatalogName { get; set; }
+ protected override string OnGetActionLogName()
+ {
+ return $"Catalog '{(CatalogName != null ? CatalogName : ColorCatalogGuid)}'";
+ }
}
}
diff --git a/Software/Visual_Studio/Tango.BL/DTO/SitesCatalogDTOBase.cs b/Software/Visual_Studio/Tango.BL/DTO/SitesCatalogDTOBase.cs
index b673d5660..8cff3d047 100644
--- a/Software/Visual_Studio/Tango.BL/DTO/SitesCatalogDTOBase.cs
+++ b/Software/Visual_Studio/Tango.BL/DTO/SitesCatalogDTOBase.cs
@@ -30,9 +30,9 @@ namespace Tango.BL.DTO
}
/// <summary>
- /// catalog guid
+ /// color catalog guid
/// </summary>
- public String CatalogGuid
+ public String ColorCatalogGuid
{
get; set;
}
diff --git a/Software/Visual_Studio/Tango.BL/DTO/SitesRmlDTO.cs b/Software/Visual_Studio/Tango.BL/DTO/SitesRmlDTO.cs
index 0a5089072..fa67f0b3c 100644
--- a/Software/Visual_Studio/Tango.BL/DTO/SitesRmlDTO.cs
+++ b/Software/Visual_Studio/Tango.BL/DTO/SitesRmlDTO.cs
@@ -10,9 +10,12 @@ namespace Tango.BL.DTO
{
public class SitesRmlDTO : SitesRmlDTOBase
{
+ [ObservableDTOProperty(MapsTo = nameof(SitesRml.Rml) + "." + nameof(SitesRml.Rml.Name))]
+ public String RmlName { get; set; }
+
protected override string OnGetActionLogName()
{
- return $"RML '{RmlGuid}'";
+ return $"RML '{(RmlName != null ? RmlName : RmlGuid)}'";
}
}
}
diff --git a/Software/Visual_Studio/Tango.BL/Entities/ColorCatalogBase.cs b/Software/Visual_Studio/Tango.BL/Entities/ColorCatalogBase.cs
index da3c15c5c..f19eda455 100644
--- a/Software/Visual_Studio/Tango.BL/Entities/ColorCatalogBase.cs
+++ b/Software/Visual_Studio/Tango.BL/Entities/ColorCatalogBase.cs
@@ -44,6 +44,8 @@ namespace Tango.BL.Entities
public event EventHandler<SynchronizedObservableCollection<Job>> JobsChanged;
+ public event EventHandler<SynchronizedObservableCollection<SitesCatalog>> SitesCatalogsChanged;
+
protected String _company;
/// <summary>
@@ -281,6 +283,31 @@ namespace Tango.BL.Entities
}
}
+ protected SynchronizedObservableCollection<SitesCatalog> _sitescatalogs;
+
+ /// <summary>
+ /// Gets or sets the colorcatalogbase sites catalogs.
+ /// </summary>
+
+ public virtual SynchronizedObservableCollection<SitesCatalog> SitesCatalogs
+ {
+ get
+ {
+ return _sitescatalogs;
+ }
+
+ set
+ {
+ if (_sitescatalogs != value)
+ {
+ _sitescatalogs = value;
+
+ OnSitesCatalogsChanged(value);
+
+ }
+ }
+ }
+
/// <summary>
/// Called when the Company has changed.
/// </summary>
@@ -363,6 +390,15 @@ namespace Tango.BL.Entities
}
/// <summary>
+ /// Called when the SitesCatalogs has changed.
+ /// </summary>
+ protected virtual void OnSitesCatalogsChanged(SynchronizedObservableCollection<SitesCatalog> sitescatalogs)
+ {
+ SitesCatalogsChanged?.Invoke(this, sitescatalogs);
+ RaisePropertyChanged(nameof(SitesCatalogs));
+ }
+
+ /// <summary>
/// Initializes a new instance of the <see cref="ColorCatalogBase" /> class.
/// </summary>
public ColorCatalogBase() : base()
@@ -374,6 +410,8 @@ namespace Tango.BL.Entities
Jobs = new SynchronizedObservableCollection<Job>();
+ SitesCatalogs = new SynchronizedObservableCollection<SitesCatalog>();
+
}
}
}
diff --git a/Software/Visual_Studio/Tango.BL/Entities/HardwareBlowerBase.cs b/Software/Visual_Studio/Tango.BL/Entities/HardwareBlowerBase.cs
index c6c166498..bbc55d245 100644
--- a/Software/Visual_Studio/Tango.BL/Entities/HardwareBlowerBase.cs
+++ b/Software/Visual_Studio/Tango.BL/Entities/HardwareBlowerBase.cs
@@ -129,6 +129,10 @@ namespace Tango.BL.Entities
/// </summary>
[Column("VOLTAGE")]
+
+ [Description("Voltage Description")]
+ [Range(-10000,1000000)]
+
public Double Voltage
{
get
diff --git a/Software/Visual_Studio/Tango.BL/Entities/OrganizationBase.cs b/Software/Visual_Studio/Tango.BL/Entities/OrganizationBase.cs
index b19cb6fc1..c83d1a7c9 100644
--- a/Software/Visual_Studio/Tango.BL/Entities/OrganizationBase.cs
+++ b/Software/Visual_Studio/Tango.BL/Entities/OrganizationBase.cs
@@ -36,6 +36,8 @@ namespace Tango.BL.Entities
public event EventHandler<SynchronizedObservableCollection<Machine>> MachinesChanged;
+ public event EventHandler<SynchronizedObservableCollection<Site>> SitesChanged;
+
public event EventHandler<SynchronizedObservableCollection<User>> UsersChanged;
protected String _name;
@@ -231,6 +233,31 @@ namespace Tango.BL.Entities
}
}
+ protected SynchronizedObservableCollection<Site> _sites;
+
+ /// <summary>
+ /// Gets or sets the organizationbase sites.
+ /// </summary>
+
+ public virtual SynchronizedObservableCollection<Site> Sites
+ {
+ get
+ {
+ return _sites;
+ }
+
+ set
+ {
+ if (_sites != value)
+ {
+ _sites = value;
+
+ OnSitesChanged(value);
+
+ }
+ }
+ }
+
protected SynchronizedObservableCollection<User> _users;
/// <summary>
@@ -302,6 +329,15 @@ namespace Tango.BL.Entities
}
/// <summary>
+ /// Called when the Sites has changed.
+ /// </summary>
+ protected virtual void OnSitesChanged(SynchronizedObservableCollection<Site> sites)
+ {
+ SitesChanged?.Invoke(this, sites);
+ RaisePropertyChanged(nameof(Sites));
+ }
+
+ /// <summary>
/// Called when the Users has changed.
/// </summary>
protected virtual void OnUsersChanged(SynchronizedObservableCollection<User> users)
@@ -320,6 +356,8 @@ namespace Tango.BL.Entities
Machines = new SynchronizedObservableCollection<Machine>();
+ Sites = new SynchronizedObservableCollection<Site>();
+
Users = new SynchronizedObservableCollection<User>();
}
diff --git a/Software/Visual_Studio/Tango.BL/Entities/RmlBase.cs b/Software/Visual_Studio/Tango.BL/Entities/RmlBase.cs
index 853372bba..86545b913 100644
--- a/Software/Visual_Studio/Tango.BL/Entities/RmlBase.cs
+++ b/Software/Visual_Studio/Tango.BL/Entities/RmlBase.cs
@@ -90,6 +90,8 @@ namespace Tango.BL.Entities
public event EventHandler<SynchronizedObservableCollection<ProcessParametersTablesGroup>> ProcessParametersTablesGroupsChanged;
+ public event EventHandler<SynchronizedObservableCollection<SitesRml>> SitesRmlsChanged;
+
protected String _name;
/// <summary>
@@ -1159,6 +1161,31 @@ namespace Tango.BL.Entities
}
}
+ protected SynchronizedObservableCollection<SitesRml> _sitesrmls;
+
+ /// <summary>
+ /// Gets or sets the rmlbase sites rmls.
+ /// </summary>
+
+ public virtual SynchronizedObservableCollection<SitesRml> SitesRmls
+ {
+ get
+ {
+ return _sitesrmls;
+ }
+
+ set
+ {
+ if (_sitesrmls != value)
+ {
+ _sitesrmls = value;
+
+ OnSitesRmlsChanged(value);
+
+ }
+ }
+ }
+
/// <summary>
/// Called when the Name has changed.
/// </summary>
@@ -1448,6 +1475,15 @@ namespace Tango.BL.Entities
}
/// <summary>
+ /// Called when the SitesRmls has changed.
+ /// </summary>
+ protected virtual void OnSitesRmlsChanged(SynchronizedObservableCollection<SitesRml> sitesrmls)
+ {
+ SitesRmlsChanged?.Invoke(this, sitesrmls);
+ RaisePropertyChanged(nameof(SitesRmls));
+ }
+
+ /// <summary>
/// Initializes a new instance of the <see cref="RmlBase" /> class.
/// </summary>
public RmlBase() : base()
@@ -1465,6 +1501,8 @@ namespace Tango.BL.Entities
ProcessParametersTablesGroups = new SynchronizedObservableCollection<ProcessParametersTablesGroup>();
+ SitesRmls = new SynchronizedObservableCollection<SitesRml>();
+
}
}
}
diff --git a/Software/Visual_Studio/Tango.BL/Entities/SiteBase.cs b/Software/Visual_Studio/Tango.BL/Entities/SiteBase.cs
index 4294b2daf..f4881ae79 100644
--- a/Software/Visual_Studio/Tango.BL/Entities/SiteBase.cs
+++ b/Software/Visual_Studio/Tango.BL/Entities/SiteBase.cs
@@ -30,6 +30,12 @@ namespace Tango.BL.Entities
public event EventHandler<String> DescriptionChanged;
+ public event EventHandler<Organization> OrganizationChanged;
+
+ public event EventHandler<SynchronizedObservableCollection<SitesCatalog>> SitesCatalogsChanged;
+
+ public event EventHandler<SynchronizedObservableCollection<SitesRml>> SitesRmlsChanged;
+
protected String _organizationguid;
/// <summary>
@@ -37,6 +43,7 @@ namespace Tango.BL.Entities
/// </summary>
[Column("ORGANIZATION_GUID")]
+ [ForeignKey("Organization")]
public String OrganizationGuid
{
@@ -109,6 +116,88 @@ namespace Tango.BL.Entities
}
}
+ protected Organization _organization;
+
+ /// <summary>
+ /// Gets or sets the sitebase organization.
+ /// </summary>
+
+ [XmlIgnore]
+ [JsonIgnore]
+ public virtual Organization Organization
+ {
+ get
+ {
+ return _organization;
+ }
+
+ set
+ {
+ if (_organization != value)
+ {
+ _organization = value;
+
+ if (Organization != null)
+ {
+ OrganizationGuid = Organization.Guid;
+ }
+
+ OnOrganizationChanged(value);
+
+ }
+ }
+ }
+
+ protected SynchronizedObservableCollection<SitesCatalog> _sitescatalogs;
+
+ /// <summary>
+ /// Gets or sets the sitebase sites catalogs.
+ /// </summary>
+
+ public virtual SynchronizedObservableCollection<SitesCatalog> SitesCatalogs
+ {
+ get
+ {
+ return _sitescatalogs;
+ }
+
+ set
+ {
+ if (_sitescatalogs != value)
+ {
+ _sitescatalogs = value;
+
+ OnSitesCatalogsChanged(value);
+
+ }
+ }
+ }
+
+ protected SynchronizedObservableCollection<SitesRml> _sitesrmls;
+
+ /// <summary>
+ /// Gets or sets the sitebase sites rmls.
+ /// </summary>
+
+ public virtual SynchronizedObservableCollection<SitesRml> SitesRmls
+ {
+ get
+ {
+ return _sitesrmls;
+ }
+
+ set
+ {
+ if (_sitesrmls != value)
+ {
+ _sitesrmls = value;
+
+ OnSitesRmlsChanged(value);
+
+ }
+ }
+ }
+
/// <summary>
/// Called when the Name has changed.
/// </summary>
@@ -128,10 +217,42 @@ namespace Tango.BL.Entities
}
/// <summary>
+ /// Called when the Organization has changed.
+ /// </summary>
+ protected virtual void OnOrganizationChanged(Organization organization)
+ {
+ OrganizationChanged?.Invoke(this, organization);
+ RaisePropertyChanged(nameof(Organization));
+ }
+
+ /// <summary>
+ /// Called when the SitesCatalogs has changed.
+ /// </summary>
+ protected virtual void OnSitesCatalogsChanged(SynchronizedObservableCollection<SitesCatalog> sitescatalogs)
+ {
+ SitesCatalogsChanged?.Invoke(this, sitescatalogs);
+ RaisePropertyChanged(nameof(SitesCatalogs));
+ }
+
+ /// <summary>
+ /// Called when the SitesRmls has changed.
+ /// </summary>
+ protected virtual void OnSitesRmlsChanged(SynchronizedObservableCollection<SitesRml> sitesrmls)
+ {
+ SitesRmlsChanged?.Invoke(this, sitesrmls);
+ RaisePropertyChanged(nameof(SitesRmls));
+ }
+
+ /// <summary>
/// Initializes a new instance of the <see cref="SiteBase" /> class.
/// </summary>
public SiteBase() : base()
{
+
+ SitesCatalogs = new SynchronizedObservableCollection<SitesCatalog>();
+
+ SitesRmls = new SynchronizedObservableCollection<SitesRml>();
+
}
}
}
diff --git a/Software/Visual_Studio/Tango.BL/Entities/SitesRmlBase.cs b/Software/Visual_Studio/Tango.BL/Entities/SitesRmlBase.cs
index 0538069b4..6893099e4 100644
--- a/Software/Visual_Studio/Tango.BL/Entities/SitesRmlBase.cs
+++ b/Software/Visual_Studio/Tango.BL/Entities/SitesRmlBase.cs
@@ -26,6 +26,10 @@ namespace Tango.BL.Entities
public abstract class SitesRmlBase : ObservableEntity<SitesRml>
{
+ public event EventHandler<Rml> RmlChanged;
+
+ public event EventHandler<Site> SiteChanged;
+
protected String _siteguid;
/// <summary>
@@ -33,6 +37,7 @@ namespace Tango.BL.Entities
/// </summary>
[Column("SITE_GUID")]
+ [ForeignKey("Site")]
public String SiteGuid
{
@@ -58,6 +63,7 @@ namespace Tango.BL.Entities
/// </summary>
[Column("RML_GUID")]
+ [ForeignKey("Rml")]
public String RmlGuid
{
@@ -76,6 +82,88 @@ namespace Tango.BL.Entities
}
}
+ protected Rml _rml;
+
+ /// <summary>
+ /// Gets or sets the sitesrmlbase rml.
+ /// </summary>
+
+ [XmlIgnore]
+ [JsonIgnore]
+ public virtual Rml Rml
+ {
+ get
+ {
+ return _rml;
+ }
+
+ set
+ {
+ if (_rml != value)
+ {
+ _rml = value;
+
+ if (Rml != null)
+ {
+ RmlGuid = Rml.Guid;
+ }
+
+ OnRmlChanged(value);
+
+ }
+ }
+ }
+
+ protected Site _site;
+
+ /// <summary>
+ /// Gets or sets the sitesrmlbase site.
+ /// </summary>
+
+ [XmlIgnore]
+ [JsonIgnore]
+ public virtual Site Site
+ {
+ get
+ {
+ return _site;
+ }
+
+ set
+ {
+ if (_site != value)
+ {
+ _site = value;
+
+ if (Site != null)
+ {
+ SiteGuid = Site.Guid;
+ }
+
+ OnSiteChanged(value);
+
+ }
+ }
+ }
+
+ /// <summary>
+ /// Called when the Rml has changed.
+ /// </summary>
+ protected virtual void OnRmlChanged(Rml rml)
+ {
+ RmlChanged?.Invoke(this, rml);
+ RaisePropertyChanged(nameof(Rml));
+ }
+
+ /// <summary>
+ /// Called when the Site has changed.
+ /// </summary>
+ protected virtual void OnSiteChanged(Site site)
+ {
+ SiteChanged?.Invoke(this, site);
+ RaisePropertyChanged(nameof(Site));
+ }
+
/// <summary>
/// Initializes a new instance of the <see cref="SitesRmlBase" /> class.
/// </summary>
diff --git a/Software/Visual_Studio/Tango.BL/Tango.BL.csproj b/Software/Visual_Studio/Tango.BL/Tango.BL.csproj
index 5c599bb5e..b55d66606 100644
--- a/Software/Visual_Studio/Tango.BL/Tango.BL.csproj
+++ b/Software/Visual_Studio/Tango.BL/Tango.BL.csproj
@@ -100,6 +100,8 @@
<Compile Include="Builders\JobBuilder.cs" />
<Compile Include="Builders\JobRunsBuilder.cs" />
<Compile Include="Builders\CatalogsCollectionBuilder.cs" />
+ <Compile Include="Builders\SiteBuilder.cs" />
+ <Compile Include="Builders\SitesCollectionBuilder.cs" />
<Compile Include="Builders\TangoUpdatesCollectionBuilder.cs" />
<Compile Include="Builders\JobsCollectionBuilder.cs" />
<Compile Include="Builders\MachineBuilder.cs" />
@@ -592,7 +594,7 @@
</Target>
<ProjectExtensions>
<VisualStudio>
- <UserProperties BuildVersion_AssemblyInfoFilename="Properties\AssemblyInfo.cs" BuildVersion_UpdateAssemblyVersion="True" BuildVersion_BuildVersioningStyle="None.None.Increment.TimeStamp" BuildVersion_UseGlobalSettings="False" BuildVersion_StartDate="2000/1/1" />
+ <UserProperties BuildVersion_StartDate="2000/1/1" BuildVersion_UseGlobalSettings="False" BuildVersion_BuildVersioningStyle="None.None.Increment.TimeStamp" BuildVersion_UpdateAssemblyVersion="True" BuildVersion_AssemblyInfoFilename="Properties\AssemblyInfo.cs" />
</VisualStudio>
</ProjectExtensions>
</Project> \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.DAL.Remote/DB/COLOR_CATALOGS.cs b/Software/Visual_Studio/Tango.DAL.Remote/DB/COLOR_CATALOGS.cs
index 31989101d..86c0156b7 100644
--- a/Software/Visual_Studio/Tango.DAL.Remote/DB/COLOR_CATALOGS.cs
+++ b/Software/Visual_Studio/Tango.DAL.Remote/DB/COLOR_CATALOGS.cs
@@ -20,6 +20,7 @@ namespace Tango.DAL.Remote.DB
this.BRUSH_STOPS = new HashSet<BRUSH_STOPS>();
this.COLOR_CATALOGS_GROUPS = new HashSet<COLOR_CATALOGS_GROUPS>();
this.JOBS = new HashSet<JOB>();
+ this.SITES_CATALOGS = new HashSet<SITES_CATALOGS>();
}
public int ID { get; set; }
@@ -38,5 +39,7 @@ namespace Tango.DAL.Remote.DB
public virtual ICollection<COLOR_CATALOGS_GROUPS> COLOR_CATALOGS_GROUPS { get; set; }
[System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly")]
public virtual ICollection<JOB> JOBS { get; set; }
+ [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly")]
+ public virtual ICollection<SITES_CATALOGS> SITES_CATALOGS { get; set; }
}
}
diff --git a/Software/Visual_Studio/Tango.DAL.Remote/DB/ORGANIZATION.cs b/Software/Visual_Studio/Tango.DAL.Remote/DB/ORGANIZATION.cs
index 0073f82ef..71be380f5 100644
--- a/Software/Visual_Studio/Tango.DAL.Remote/DB/ORGANIZATION.cs
+++ b/Software/Visual_Studio/Tango.DAL.Remote/DB/ORGANIZATION.cs
@@ -19,6 +19,7 @@ namespace Tango.DAL.Remote.DB
{
this.CUSTOMERS = new HashSet<CUSTOMER>();
this.MACHINES = new HashSet<MACHINE>();
+ this.SITES = new HashSet<SITE>();
this.USERS = new HashSet<USER>();
}
@@ -36,6 +37,8 @@ namespace Tango.DAL.Remote.DB
[System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly")]
public virtual ICollection<MACHINE> MACHINES { get; set; }
[System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly")]
+ public virtual ICollection<SITE> SITES { get; set; }
+ [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly")]
public virtual ICollection<USER> USERS { get; set; }
}
}
diff --git a/Software/Visual_Studio/Tango.DAL.Remote/DB/RML.cs b/Software/Visual_Studio/Tango.DAL.Remote/DB/RML.cs
index 063cd7f8e..15c59c062 100644
--- a/Software/Visual_Studio/Tango.DAL.Remote/DB/RML.cs
+++ b/Software/Visual_Studio/Tango.DAL.Remote/DB/RML.cs
@@ -23,6 +23,7 @@ namespace Tango.DAL.Remote.DB
this.LIQUID_TYPES_RMLS = new HashSet<LIQUID_TYPES_RMLS>();
this.MACHINES = new HashSet<MACHINE>();
this.PROCESS_PARAMETERS_TABLES_GROUPS = new HashSet<PROCESS_PARAMETERS_TABLES_GROUPS>();
+ this.SITES_RMLS = new HashSet<SITES_RMLS>();
}
public int ID { get; set; }
@@ -74,5 +75,7 @@ namespace Tango.DAL.Remote.DB
public virtual MEDIA_PURPOSES MEDIA_PURPOSES { get; set; }
[System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly")]
public virtual ICollection<PROCESS_PARAMETERS_TABLES_GROUPS> PROCESS_PARAMETERS_TABLES_GROUPS { get; set; }
+ [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly")]
+ public virtual ICollection<SITES_RMLS> SITES_RMLS { get; set; }
}
}
diff --git a/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.Designer.cs b/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.Designer.cs
index 17bc2683d..d26e67908 100644
--- a/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.Designer.cs
+++ b/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.Designer.cs
@@ -1,4 +1,4 @@
-// T4 code generation is enabled for model 'D:\Development\Tango\Software\Visual_Studio\Tango.DAL.Remote\DB\RemoteADO.edmx'.
+// T4 code generation is enabled for model 'C:\DATA\Development\Tango\Software\Visual_Studio\Tango.DAL.Remote\DB\RemoteADO.edmx'.
// To enable legacy code generation, change the value of the 'Code Generation Strategy' designer
// property to 'Legacy ObjectContext'. This property is available in the Properties Window when the model
// is open in the designer.
diff --git a/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx b/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx
index eb161228c..9b55ede6e 100644
--- a/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx
+++ b/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx
@@ -957,7 +957,7 @@
<Property Name="GUID" Type="varchar" MaxLength="36" Nullable="false" />
<Property Name="LAST_UPDATED" Type="datetime2" Precision="3" Nullable="false" />
<Property Name="SITE_GUID" Type="varchar" MaxLength="36" Nullable="false" />
- <Property Name="CATALOG_GUID" Type="varchar" MaxLength="36" Nullable="false" />
+ <Property Name="COLOR_CATALOG_GUID" Type="varchar" MaxLength="36" Nullable="false" />
</EntityType>
<EntityType Name="SITES_RMLS">
<Key>
@@ -2115,6 +2115,74 @@
</Dependent>
</ReferentialConstraint>
</Association>
+ <Association Name="FK_SITES_CATALOGS_COLOR_CATALOGS">
+ <End Role="COLOR_CATALOGS" Type="Self.COLOR_CATALOGS" Multiplicity="1">
+ <OnDelete Action="Cascade" />
+ </End>
+ <End Role="SITES_CATALOGS" Type="Self.SITES_CATALOGS" Multiplicity="*" />
+ <ReferentialConstraint>
+ <Principal Role="COLOR_CATALOGS">
+ <PropertyRef Name="GUID" />
+ </Principal>
+ <Dependent Role="SITES_CATALOGS">
+ <PropertyRef Name="COLOR_CATALOG_GUID" />
+ </Dependent>
+ </ReferentialConstraint>
+ </Association>
+ <Association Name="FK_SITES_CATALOGS_SITES">
+ <End Role="SITES" Type="Self.SITES" Multiplicity="1">
+ <OnDelete Action="Cascade" />
+ </End>
+ <End Role="SITES_CATALOGS" Type="Self.SITES_CATALOGS" Multiplicity="*" />
+ <ReferentialConstraint>
+ <Principal Role="SITES">
+ <PropertyRef Name="GUID" />
+ </Principal>
+ <Dependent Role="SITES_CATALOGS">
+ <PropertyRef Name="SITE_GUID" />
+ </Dependent>
+ </ReferentialConstraint>
+ </Association>
+ <Association Name="FK_SITES_ORGANIZATIONS">
+ <End Role="ORGANIZATIONS" Type="Self.ORGANIZATIONS" Multiplicity="1" />
+ <End Role="SITES" Type="Self.SITES" Multiplicity="*" />
+ <ReferentialConstraint>
+ <Principal Role="ORGANIZATIONS">
+ <PropertyRef Name="GUID" />
+ </Principal>
+ <Dependent Role="SITES">
+ <PropertyRef Name="ORGANIZATION_GUID" />
+ </Dependent>
+ </ReferentialConstraint>
+ </Association>
+ <Association Name="FK_SITES_RMLS_RMLS">
+ <End Role="RMLS" Type="Self.RMLS" Multiplicity="1">
+ <OnDelete Action="Cascade" />
+ </End>
+ <End Role="SITES_RMLS" Type="Self.SITES_RMLS" Multiplicity="*" />
+ <ReferentialConstraint>
+ <Principal Role="RMLS">
+ <PropertyRef Name="GUID" />
+ </Principal>
+ <Dependent Role="SITES_RMLS">
+ <PropertyRef Name="RML_GUID" />
+ </Dependent>
+ </ReferentialConstraint>
+ </Association>
+ <Association Name="FK_SITES_RMLS_SITES">
+ <End Role="SITES" Type="Self.SITES" Multiplicity="1">
+ <OnDelete Action="Cascade" />
+ </End>
+ <End Role="SITES_RMLS" Type="Self.SITES_RMLS" Multiplicity="*" />
+ <ReferentialConstraint>
+ <Principal Role="SITES">
+ <PropertyRef Name="GUID" />
+ </Principal>
+ <Dependent Role="SITES_RMLS">
+ <PropertyRef Name="SITE_GUID" />
+ </Dependent>
+ </ReferentialConstraint>
+ </Association>
<Association Name="FK_SPOOLS_MACHINES">
<End Role="MACHINES" Type="Self.MACHINES" Multiplicity="1">
<OnDelete Action="Cascade" />
@@ -2601,6 +2669,26 @@
<End Role="JOBS" EntitySet="JOBS" />
<End Role="SEGMENTS" EntitySet="SEGMENTS" />
</AssociationSet>
+ <AssociationSet Name="FK_SITES_CATALOGS_COLOR_CATALOGS" Association="Self.FK_SITES_CATALOGS_COLOR_CATALOGS">
+ <End Role="COLOR_CATALOGS" EntitySet="COLOR_CATALOGS" />
+ <End Role="SITES_CATALOGS" EntitySet="SITES_CATALOGS" />
+ </AssociationSet>
+ <AssociationSet Name="FK_SITES_CATALOGS_SITES" Association="Self.FK_SITES_CATALOGS_SITES">
+ <End Role="SITES" EntitySet="SITES" />
+ <End Role="SITES_CATALOGS" EntitySet="SITES_CATALOGS" />
+ </AssociationSet>
+ <AssociationSet Name="FK_SITES_ORGANIZATIONS" Association="Self.FK_SITES_ORGANIZATIONS">
+ <End Role="ORGANIZATIONS" EntitySet="ORGANIZATIONS" />
+ <End Role="SITES" EntitySet="SITES" />
+ </AssociationSet>
+ <AssociationSet Name="FK_SITES_RMLS_RMLS" Association="Self.FK_SITES_RMLS_RMLS">
+ <End Role="RMLS" EntitySet="RMLS" />
+ <End Role="SITES_RMLS" EntitySet="SITES_RMLS" />
+ </AssociationSet>
+ <AssociationSet Name="FK_SITES_RMLS_SITES" Association="Self.FK_SITES_RMLS_SITES">
+ <End Role="SITES" EntitySet="SITES" />
+ <End Role="SITES_RMLS" EntitySet="SITES_RMLS" />
+ </AssociationSet>
<AssociationSet Name="FK_SPOOLS_MACHINES" Association="Self.FK_SPOOLS_MACHINES">
<End Role="MACHINES" EntitySet="MACHINES" />
<End Role="SPOOLS" EntitySet="SPOOLS" />
@@ -2790,6 +2878,10 @@
<End Role="COLOR_CATALOGS" EntitySet="COLOR_CATALOGS" />
<End Role="JOB" EntitySet="JOBS" />
</AssociationSet>
+ <AssociationSet Name="FK_SITES_CATALOGS_COLOR_CATALOGS" Association="RemoteModel.FK_SITES_CATALOGS_COLOR_CATALOGS">
+ <End Role="COLOR_CATALOGS" EntitySet="COLOR_CATALOGS" />
+ <End Role="SITES_CATALOGS" EntitySet="SITES_CATALOGS" />
+ </AssociationSet>
<AssociationSet Name="FK_COLOR_CATALOGS_ITEMS_COLOR_CATALOGS_GROUPS" Association="RemoteModel.FK_COLOR_CATALOGS_ITEMS_COLOR_CATALOGS_GROUPS">
<End Role="COLOR_CATALOGS_GROUPS" EntitySet="COLOR_CATALOGS_GROUPS" />
<End Role="COLOR_CATALOGS_ITEMS" EntitySet="COLOR_CATALOGS_ITEMS" />
@@ -3014,6 +3106,10 @@
<End Role="MEDIA_PURPOSES" EntitySet="MEDIA_PURPOSES" />
<End Role="RML" EntitySet="RMLS" />
</AssociationSet>
+ <AssociationSet Name="FK_SITES_ORGANIZATIONS" Association="RemoteModel.FK_SITES_ORGANIZATIONS">
+ <End Role="ORGANIZATION" EntitySet="ORGANIZATIONS" />
+ <End Role="SITE" EntitySet="SITES" />
+ </AssociationSet>
<AssociationSet Name="FK_USERS_ORGANIZATIONS" Association="RemoteModel.FK_USERS_ORGANIZATIONS">
<End Role="ORGANIZATION" EntitySet="ORGANIZATIONS" />
<End Role="USER" EntitySet="USERS" />
@@ -3030,6 +3126,10 @@
<End Role="RML" EntitySet="RMLS" />
<End Role="PROCESS_PARAMETERS_TABLES_GROUPS" EntitySet="PROCESS_PARAMETERS_TABLES_GROUPS" />
</AssociationSet>
+ <AssociationSet Name="FK_SITES_RMLS_RMLS" Association="RemoteModel.FK_SITES_RMLS_RMLS">
+ <End Role="RML" EntitySet="RMLS" />
+ <End Role="SITES_RMLS" EntitySet="SITES_RMLS" />
+ </AssociationSet>
<AssociationSet Name="FK_ROLES_PERMISSIONS_ROLES" Association="RemoteModel.FK_ROLES_PERMISSIONS_ROLES">
<End Role="ROLE" EntitySet="ROLES" />
<End Role="ROLES_PERMISSIONS" EntitySet="ROLES_PERMISSIONS" />
@@ -3038,6 +3138,14 @@
<End Role="ROLE" EntitySet="ROLES" />
<End Role="USERS_ROLES" EntitySet="USERS_ROLES" />
</AssociationSet>
+ <AssociationSet Name="FK_SITES_CATALOGS_SITES" Association="RemoteModel.FK_SITES_CATALOGS_SITES">
+ <End Role="SITE" EntitySet="SITES" />
+ <End Role="SITES_CATALOGS" EntitySet="SITES_CATALOGS" />
+ </AssociationSet>
+ <AssociationSet Name="FK_SITES_RMLS_SITES" Association="RemoteModel.FK_SITES_RMLS_SITES">
+ <End Role="SITE" EntitySet="SITES" />
+ <End Role="SITES_RMLS" EntitySet="SITES_RMLS" />
+ </AssociationSet>
<AssociationSet Name="FK_SPOOLS_SPOOL_TYPES" Association="RemoteModel.FK_SPOOLS_SPOOL_TYPES">
<End Role="SPOOL_TYPES" EntitySet="SPOOL_TYPES" />
<End Role="SPOOL" EntitySet="SPOOLS" />
@@ -3226,6 +3334,7 @@
<NavigationProperty Name="BRUSH_STOPS" Relationship="RemoteModel.FK_BRUSH_STOPS_COLOR_CATALOGS" FromRole="COLOR_CATALOGS" ToRole="BRUSH_STOPS" />
<NavigationProperty Name="COLOR_CATALOGS_GROUPS" Relationship="RemoteModel.FK_COLOR_CATALOGS_GROUPS_COLOR_CATALOGS" FromRole="COLOR_CATALOGS" ToRole="COLOR_CATALOGS_GROUPS" />
<NavigationProperty Name="JOBS" Relationship="RemoteModel.FK_JOBS_COLOR_CATALOGS" FromRole="COLOR_CATALOGS" ToRole="JOB" />
+ <NavigationProperty Name="SITES_CATALOGS" Relationship="RemoteModel.FK_SITES_CATALOGS_COLOR_CATALOGS" FromRole="COLOR_CATALOGS" ToRole="SITES_CATALOGS" />
</EntityType>
<EntityType Name="COLOR_CATALOGS_GROUPS">
<Key>
@@ -3992,6 +4101,7 @@
<NavigationProperty Name="CONTACT" Relationship="RemoteModel.FK_ORGANIZATIONS_CONTACTS" FromRole="ORGANIZATION" ToRole="CONTACT" />
<NavigationProperty Name="CUSTOMERS" Relationship="RemoteModel.FK_CUSTOMERS_ORGANIZATIONS" FromRole="ORGANIZATION" ToRole="CUSTOMER" />
<NavigationProperty Name="MACHINES" Relationship="RemoteModel.FK_MACHINES_ORGANIZATIONS" FromRole="ORGANIZATION" ToRole="MACHINE" />
+ <NavigationProperty Name="SITES" Relationship="RemoteModel.FK_SITES_ORGANIZATIONS" FromRole="ORGANIZATION" ToRole="SITE" />
<NavigationProperty Name="USERS" Relationship="RemoteModel.FK_USERS_ORGANIZATIONS" FromRole="ORGANIZATION" ToRole="USER" />
</EntityType>
<EntityType Name="PERMISSION">
@@ -4097,6 +4207,7 @@
<NavigationProperty Name="MEDIA_MATERIALS" Relationship="RemoteModel.FK_RML_MEDIA_MATERIALS" FromRole="RML" ToRole="MEDIA_MATERIALS" />
<NavigationProperty Name="MEDIA_PURPOSES" Relationship="RemoteModel.FK_RML_MEDIA_PURPOSES" FromRole="RML" ToRole="MEDIA_PURPOSES" />
<NavigationProperty Name="PROCESS_PARAMETERS_TABLES_GROUPS" Relationship="RemoteModel.FK_PROCESS_PARAMETERS_TABLES_GROUPS_RMLS" FromRole="RML" ToRole="PROCESS_PARAMETERS_TABLES_GROUPS" />
+ <NavigationProperty Name="SITES_RMLS" Relationship="RemoteModel.FK_SITES_RMLS_RMLS" FromRole="RML" ToRole="SITES_RMLS" />
</EntityType>
<EntityType Name="ROLE">
<Key>
@@ -4147,6 +4258,9 @@
<Property Name="ORGANIZATION_GUID" Type="String" Nullable="false" MaxLength="36" FixedLength="false" Unicode="false" />
<Property Name="NAME" Type="String" Nullable="false" MaxLength="100" FixedLength="false" Unicode="true" />
<Property Name="DESCRIPTION" Type="String" MaxLength="200" FixedLength="false" Unicode="true" />
+ <NavigationProperty Name="ORGANIZATION" Relationship="RemoteModel.FK_SITES_ORGANIZATIONS" FromRole="SITE" ToRole="ORGANIZATION" />
+ <NavigationProperty Name="SITES_CATALOGS" Relationship="RemoteModel.FK_SITES_CATALOGS_SITES" FromRole="SITE" ToRole="SITES_CATALOGS" />
+ <NavigationProperty Name="SITES_RMLS" Relationship="RemoteModel.FK_SITES_RMLS_SITES" FromRole="SITE" ToRole="SITES_RMLS" />
</EntityType>
<EntityType Name="SITES_CATALOGS">
<Key>
@@ -4156,7 +4270,9 @@
<Property Name="GUID" Type="String" Nullable="false" MaxLength="36" FixedLength="false" Unicode="false" />
<Property Name="LAST_UPDATED" Type="DateTime" Nullable="false" Precision="3" />
<Property Name="SITE_GUID" Type="String" Nullable="false" MaxLength="36" FixedLength="false" Unicode="false" />
- <Property Name="CATALOG_GUID" Type="String" Nullable="false" MaxLength="36" FixedLength="false" Unicode="false" />
+ <Property Name="COLOR_CATALOG_GUID" Type="String" Nullable="false" MaxLength="36" FixedLength="false" Unicode="false" />
+ <NavigationProperty Name="COLOR_CATALOGS" Relationship="RemoteModel.FK_SITES_CATALOGS_COLOR_CATALOGS" FromRole="SITES_CATALOGS" ToRole="COLOR_CATALOGS" />
+ <NavigationProperty Name="SITE" Relationship="RemoteModel.FK_SITES_CATALOGS_SITES" FromRole="SITES_CATALOGS" ToRole="SITE" />
</EntityType>
<EntityType Name="SITES_RMLS">
<Key>
@@ -4167,6 +4283,8 @@
<Property Name="LAST_UPDATED" Type="DateTime" Nullable="false" Precision="3" />
<Property Name="SITE_GUID" Type="String" Nullable="false" MaxLength="36" FixedLength="false" Unicode="false" />
<Property Name="RML_GUID" Type="String" Nullable="false" MaxLength="36" FixedLength="false" Unicode="false" />
+ <NavigationProperty Name="RML" Relationship="RemoteModel.FK_SITES_RMLS_RMLS" FromRole="SITES_RMLS" ToRole="RML" />
+ <NavigationProperty Name="SITE" Relationship="RemoteModel.FK_SITES_RMLS_SITES" FromRole="SITES_RMLS" ToRole="SITE" />
</EntityType>
<EntityType Name="SPOOL_TYPES">
<Key>
@@ -4595,6 +4713,20 @@
</Dependent>
</ReferentialConstraint>
</Association>
+ <Association Name="FK_SITES_CATALOGS_COLOR_CATALOGS">
+ <End Type="RemoteModel.COLOR_CATALOGS" Role="COLOR_CATALOGS" Multiplicity="1">
+ <OnDelete Action="Cascade" />
+ </End>
+ <End Type="RemoteModel.SITES_CATALOGS" Role="SITES_CATALOGS" Multiplicity="*" />
+ <ReferentialConstraint>
+ <Principal Role="COLOR_CATALOGS">
+ <PropertyRef Name="GUID" />
+ </Principal>
+ <Dependent Role="SITES_CATALOGS">
+ <PropertyRef Name="COLOR_CATALOG_GUID" />
+ </Dependent>
+ </ReferentialConstraint>
+ </Association>
<Association Name="FK_COLOR_CATALOGS_ITEMS_COLOR_CATALOGS_GROUPS">
<End Type="RemoteModel.COLOR_CATALOGS_GROUPS" Role="COLOR_CATALOGS_GROUPS" Multiplicity="1">
<OnDelete Action="Cascade" />
@@ -5319,6 +5451,18 @@
</Dependent>
</ReferentialConstraint>
</Association>
+ <Association Name="FK_SITES_ORGANIZATIONS">
+ <End Type="RemoteModel.ORGANIZATION" Role="ORGANIZATION" Multiplicity="1" />
+ <End Type="RemoteModel.SITE" Role="SITE" Multiplicity="*" />
+ <ReferentialConstraint>
+ <Principal Role="ORGANIZATION">
+ <PropertyRef Name="GUID" />
+ </Principal>
+ <Dependent Role="SITE">
+ <PropertyRef Name="ORGANIZATION_GUID" />
+ </Dependent>
+ </ReferentialConstraint>
+ </Association>
<Association Name="FK_USERS_ORGANIZATIONS">
<End Type="RemoteModel.ORGANIZATION" Role="ORGANIZATION" Multiplicity="1" />
<End Type="RemoteModel.USER" Role="USER" Multiplicity="*" />
@@ -5373,6 +5517,20 @@
</Dependent>
</ReferentialConstraint>
</Association>
+ <Association Name="FK_SITES_RMLS_RMLS">
+ <End Type="RemoteModel.RML" Role="RML" Multiplicity="1">
+ <OnDelete Action="Cascade" />
+ </End>
+ <End Type="RemoteModel.SITES_RMLS" Role="SITES_RMLS" Multiplicity="*" />
+ <ReferentialConstraint>
+ <Principal Role="RML">
+ <PropertyRef Name="GUID" />
+ </Principal>
+ <Dependent Role="SITES_RMLS">
+ <PropertyRef Name="RML_GUID" />
+ </Dependent>
+ </ReferentialConstraint>
+ </Association>
<Association Name="FK_ROLES_PERMISSIONS_ROLES">
<End Type="RemoteModel.ROLE" Role="ROLE" Multiplicity="1">
<OnDelete Action="Cascade" />
@@ -5401,6 +5559,34 @@
</Dependent>
</ReferentialConstraint>
</Association>
+ <Association Name="FK_SITES_CATALOGS_SITES">
+ <End Type="RemoteModel.SITE" Role="SITE" Multiplicity="1">
+ <OnDelete Action="Cascade" />
+ </End>
+ <End Type="RemoteModel.SITES_CATALOGS" Role="SITES_CATALOGS" Multiplicity="*" />
+ <ReferentialConstraint>
+ <Principal Role="SITE">
+ <PropertyRef Name="GUID" />
+ </Principal>
+ <Dependent Role="SITES_CATALOGS">
+ <PropertyRef Name="SITE_GUID" />
+ </Dependent>
+ </ReferentialConstraint>
+ </Association>
+ <Association Name="FK_SITES_RMLS_SITES">
+ <End Type="RemoteModel.SITE" Role="SITE" Multiplicity="1">
+ <OnDelete Action="Cascade" />
+ </End>
+ <End Type="RemoteModel.SITES_RMLS" Role="SITES_RMLS" Multiplicity="*" />
+ <ReferentialConstraint>
+ <Principal Role="SITE">
+ <PropertyRef Name="GUID" />
+ </Principal>
+ <Dependent Role="SITES_RMLS">
+ <PropertyRef Name="SITE_GUID" />
+ </Dependent>
+ </ReferentialConstraint>
+ </Association>
<Association Name="FK_SPOOLS_SPOOL_TYPES">
<End Type="RemoteModel.SPOOL_TYPES" Role="SPOOL_TYPES" Multiplicity="1">
<OnDelete Action="Cascade" />
@@ -6463,7 +6649,7 @@
<EntitySetMapping Name="SITES_CATALOGS">
<EntityTypeMapping TypeName="RemoteModel.SITES_CATALOGS">
<MappingFragment StoreEntitySet="SITES_CATALOGS">
- <ScalarProperty Name="CATALOG_GUID" ColumnName="CATALOG_GUID" />
+ <ScalarProperty Name="COLOR_CATALOG_GUID" ColumnName="COLOR_CATALOG_GUID" />
<ScalarProperty Name="SITE_GUID" ColumnName="SITE_GUID" />
<ScalarProperty Name="LAST_UPDATED" ColumnName="LAST_UPDATED" />
<ScalarProperty Name="GUID" ColumnName="GUID" />
diff --git a/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx.diagram b/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx.diagram
index a9ff9aacf..77bf89743 100644
--- a/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx.diagram
+++ b/Software/Visual_Studio/Tango.DAL.Remote/DB/RemoteADO.edmx.diagram
@@ -5,84 +5,84 @@
<!-- Diagram content (shape and connector positions) -->
<edmx:Diagrams>
<Diagram DiagramId="f9ae01d708754bbd997add25a4bacc79" Name="Diagram1">
- <EntityTypeShape EntityType="RemoteModel.ACTION_LOGS" Width="1.5" PointX="13.5" PointY="63.875" />
- <EntityTypeShape EntityType="RemoteModel.ADDRESS" Width="1.5" PointX="6.75" PointY="11" />
- <EntityTypeShape EntityType="RemoteModel.APPLICATION_DISPLAY_PANEL_VERSIONS" Width="1.5" PointX="6.75" PointY="40.5" />
- <EntityTypeShape EntityType="RemoteModel.APPLICATION_FIRMWARE_VERSIONS" Width="1.5" PointX="6.75" PointY="27.375" />
- <EntityTypeShape EntityType="RemoteModel.APPLICATION_OS_VERSIONS" Width="1.5" PointX="6.75" PointY="33.25" />
- <EntityTypeShape EntityType="RemoteModel.BRUSH_STOPS" Width="1.5" PointX="18" PointY="19.875" />
- <EntityTypeShape EntityType="RemoteModel.CARTRIDGE_TYPES" Width="1.5" PointX="17" PointY="11.875" />
- <EntityTypeShape EntityType="RemoteModel.CAT" Width="1.5" PointX="5.25" PointY="22.75" />
- <EntityTypeShape EntityType="RemoteModel.CCT" Width="1.5" PointX="0.75" PointY="29.5" />
- <EntityTypeShape EntityType="RemoteModel.COLOR_CATALOGS" Width="1.5" PointX="1.5" PointY="6.625" />
- <EntityTypeShape EntityType="RemoteModel.COLOR_CATALOGS_GROUPS" Width="1.5" PointX="3.75" PointY="7" />
- <EntityTypeShape EntityType="RemoteModel.COLOR_CATALOGS_ITEMS" Width="1.5" PointX="6" PointY="0.75" />
- <EntityTypeShape EntityType="RemoteModel.COLOR_CATALOGS_ITEMS_RECIPES" Width="1.5" PointX="8.25" PointY="22.625" />
- <EntityTypeShape EntityType="RemoteModel.COLOR_SPACES" Width="1.5" PointX="9" PointY="38.375" />
- <EntityTypeShape EntityType="RemoteModel.CONFIGURATION" Width="1.5" PointX="9" PointY="33" />
- <EntityTypeShape EntityType="RemoteModel.CONTACT" Width="1.5" PointX="6.75" PointY="7.125" />
- <EntityTypeShape EntityType="RemoteModel.CUSTOMER" Width="1.5" PointX="11.25" PointY="30" />
- <EntityTypeShape EntityType="RemoteModel.DISPENSER_TYPES" Width="1.5" PointX="14.75" PointY="51.75" />
- <EntityTypeShape EntityType="RemoteModel.DISPENSER" Width="1.5" PointX="17" PointY="51.125" />
- <EntityTypeShape EntityType="RemoteModel.EMBEDDED_FIRMWARE_VERSIONS" Width="1.5" PointX="6.75" PointY="30.375" />
- <EntityTypeShape EntityType="RemoteModel.EVENT_TYPES" Width="1.5" PointX="14.25" PointY="30.25" />
- <EntityTypeShape EntityType="RemoteModel.FIBER_SHAPES" Width="1.5" PointX="0.75" PointY="23.25" />
- <EntityTypeShape EntityType="RemoteModel.FIBER_SYNTHS" Width="1.5" PointX="0.75" PointY="15.75" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_BLOWER_TYPES" Width="1.5" PointX="12.75" PointY="55.75" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_BLOWERS" Width="1.5" PointX="15" PointY="36.375" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_BREAK_SENSOR_TYPES" Width="1.5" PointX="9.75" PointY="46.75" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_BREAK_SENSORS" Width="1.5" PointX="12" PointY="38.5" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_DANCER_TYPES" Width="1.5" PointX="12.75" PointY="59.75" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_DANCERS" Width="1.5" PointX="15" PointY="40.75" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_MOTOR_TYPES" Width="1.5" PointX="9.75" PointY="50.625" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_MOTORS" Width="1.5" PointX="12" PointY="42.5" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_PID_CONTROL_TYPES" Width="1.5" PointX="15.75" PointY="19.75" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_PID_CONTROLS" Width="1.5" PointX="18" PointY="35.875" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_SPEED_SENSOR_TYPES" Width="1.5" PointX="15.75" PointY="58.75" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_SPEED_SENSORS" Width="1.5" PointX="18" PointY="43.5" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_VERSIONS" Width="1.5" PointX="6.75" PointY="36.25" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_WINDER_TYPES" Width="1.5" PointX="6.75" PointY="15.75" />
- <EntityTypeShape EntityType="RemoteModel.HARDWARE_WINDERS" Width="1.5" PointX="9" PointY="28.625" />
- <EntityTypeShape EntityType="RemoteModel.IDS_PACK_FORMULAS" Width="1.5" PointX="17" PointY="47.875" />
- <EntityTypeShape EntityType="RemoteModel.IDS_PACKS" Width="1.5" PointX="19.25" PointY="30.25" />
- <EntityTypeShape EntityType="RemoteModel.JOB_RUNS" Width="1.5" PointX="8.75" PointY="3.125" />
- <EntityTypeShape EntityType="RemoteModel.JOB" Width="1.5" PointX="13.5" PointY="19.25" />
- <EntityTypeShape EntityType="RemoteModel.LINEAR_MASS_DENSITY_UNITS" Width="1.5" PointX="0.75" PointY="18.625" />
- <EntityTypeShape EntityType="RemoteModel.LIQUID_TYPES" Width="1.5" PointX="3" PointY="15.625" />
- <EntityTypeShape EntityType="RemoteModel.LIQUID_TYPES_RMLS" Width="1.5" PointX="5.25" PointY="18.875" />
- <EntityTypeShape EntityType="RemoteModel.MACHINE_STUDIO_VERSIONS" Width="1.5" PointX="13.5" PointY="15.125" />
- <EntityTypeShape EntityType="RemoteModel.MACHINE_VERSIONS" Width="1.5" PointX="9" PointY="15.125" />
- <EntityTypeShape EntityType="RemoteModel.MACHINE" Width="1.5" PointX="11.25" PointY="19.625" />
- <EntityTypeShape EntityType="RemoteModel.MACHINES_EVENTS" Width="1.5" PointX="16.5" PointY="29.5" />
- <EntityTypeShape EntityType="RemoteModel.MEDIA_CONDITIONS" Width="1.5" PointX="0.75" PointY="35.75" />
- <EntityTypeShape EntityType="RemoteModel.MEDIA_MATERIALS" Width="1.5" PointX="0.75" PointY="32.75" />
- <EntityTypeShape EntityType="RemoteModel.MEDIA_PURPOSES" Width="1.5" PointX="0.75" PointY="26.5" />
- <EntityTypeShape EntityType="RemoteModel.MID_TANK_TYPES" Width="1.5" PointX="17" PointY="55.375" />
- <EntityTypeShape EntityType="RemoteModel.ORGANIZATION" Width="1.5" PointX="9" PointY="9.25" />
- <EntityTypeShape EntityType="RemoteModel.PERMISSION" Width="1.5" PointX="18.25" PointY="63.25" />
- <EntityTypeShape EntityType="RemoteModel.PROCESS_PARAMETERS_TABLES" Width="1.5" PointX="7.5" PointY="53.625" />
- <EntityTypeShape EntityType="RemoteModel.PROCESS_PARAMETERS_TABLES_GROUPS" Width="1.5" PointX="5.25" PointY="55.25" />
- <EntityTypeShape EntityType="RemoteModel.RML" Width="1.5" PointX="3" PointY="19.75" />
- <EntityTypeShape EntityType="RemoteModel.ROLE" Width="1.5" PointX="18.25" PointY="59.125" />
- <EntityTypeShape EntityType="RemoteModel.ROLES_PERMISSIONS" Width="1.5" PointX="20.5" PointY="59.25" />
- <EntityTypeShape EntityType="RemoteModel.SEGMENT" Width="1.5" PointX="15.75" PointY="22.875" />
- <EntityTypeShape EntityType="RemoteModel.SITE" Width="1.5" PointX="0.75" PointY="3.125" />
- <EntityTypeShape EntityType="RemoteModel.SITES_CATALOGS" Width="1.5" PointX="2.75" PointY="3.125" />
- <EntityTypeShape EntityType="RemoteModel.SITES_RMLS" Width="1.5" PointX="0.75" PointY="11.125" />
- <EntityTypeShape EntityType="RemoteModel.SPOOL_TYPES" Width="1.5" PointX="9" PointY="42.125" />
- <EntityTypeShape EntityType="RemoteModel.SPOOL" Width="1.5" PointX="16.5" PointY="15.75" />
- <EntityTypeShape EntityType="RemoteModel.sysdiagram" Width="1.5" PointX="2.75" PointY="11.125" />
- <EntityTypeShape EntityType="RemoteModel.TANGO_UPDATES" Width="1.5" PointX="10.75" PointY="3.125" />
- <EntityTypeShape EntityType="RemoteModel.TANGO_VERSIONS" Width="1.5" PointX="20.5" PointY="24.75" />
- <EntityTypeShape EntityType="RemoteModel.TECH_CONTROLLERS" Width="1.5" PointX="11.75" PointY="8.125" />
- <EntityTypeShape EntityType="RemoteModel.TECH_DISPENSERS" Width="1.5" PointX="11.75" PointY="12.125" />
- <EntityTypeShape EntityType="RemoteModel.TECH_HEATERS" Width="1.5" PointX="12.75" PointY="3.125" />
- <EntityTypeShape EntityType="RemoteModel.TECH_IOS" Width="1.5" PointX="13.75" PointY="6.125" />
- <EntityTypeShape EntityType="RemoteModel.TECH_MONITORS" Width="1.5" PointX="15.75" PointY="3.125" />
- <EntityTypeShape EntityType="RemoteModel.TECH_VALVES" Width="1.5" PointX="13.75" PointY="11.125" />
- <EntityTypeShape EntityType="RemoteModel.USER" Width="1.5" PointX="11.25" PointY="33" />
- <EntityTypeShape EntityType="RemoteModel.USERS_ROLES" Width="1.5" PointX="20.5" PointY="35.25" />
- <EntityTypeShape EntityType="RemoteModel.WINDING_METHODS" Width="1.5" PointX="11.25" PointY="15.875" />
+ <EntityTypeShape EntityType="RemoteModel.ACTION_LOGS" Width="1.5" PointX="13.5" PointY="54.5" />
+ <EntityTypeShape EntityType="RemoteModel.ADDRESS" Width="1.5" PointX="1.5" PointY="0.875" />
+ <EntityTypeShape EntityType="RemoteModel.APPLICATION_DISPLAY_PANEL_VERSIONS" Width="1.5" PointX="6.75" PointY="26.5" />
+ <EntityTypeShape EntityType="RemoteModel.APPLICATION_FIRMWARE_VERSIONS" Width="1.5" PointX="6.75" PointY="33.75" />
+ <EntityTypeShape EntityType="RemoteModel.APPLICATION_OS_VERSIONS" Width="1.5" PointX="6.75" PointY="39.625" />
+ <EntityTypeShape EntityType="RemoteModel.BRUSH_STOPS" Width="1.5" PointX="19" PointY="23.125" />
+ <EntityTypeShape EntityType="RemoteModel.CARTRIDGE_TYPES" Width="1.5" PointX="19.25" PointY="12" />
+ <EntityTypeShape EntityType="RemoteModel.CAT" Width="1.5" PointX="16.5" PointY="22" />
+ <EntityTypeShape EntityType="RemoteModel.CCT" Width="1.5" PointX="0.75" PointY="25.875" />
+ <EntityTypeShape EntityType="RemoteModel.COLOR_CATALOGS" Width="1.5" PointX="1.5" PointY="44.875" />
+ <EntityTypeShape EntityType="RemoteModel.COLOR_CATALOGS_GROUPS" Width="1.5" PointX="0.75" PointY="39.375" />
+ <EntityTypeShape EntityType="RemoteModel.COLOR_CATALOGS_ITEMS" Width="1.5" PointX="3" PointY="38.125" />
+ <EntityTypeShape EntityType="RemoteModel.COLOR_CATALOGS_ITEMS_RECIPES" Width="1.5" PointX="5.25" PointY="22" />
+ <EntityTypeShape EntityType="RemoteModel.COLOR_SPACES" Width="1.5" PointX="9" PointY="17.875" />
+ <EntityTypeShape EntityType="RemoteModel.CONFIGURATION" Width="1.5" PointX="9" PointY="32.125" />
+ <EntityTypeShape EntityType="RemoteModel.CONTACT" Width="1.5" PointX="1.5" PointY="5" />
+ <EntityTypeShape EntityType="RemoteModel.CUSTOMER" Width="1.5" PointX="11.25" PointY="29.25" />
+ <EntityTypeShape EntityType="RemoteModel.DISPENSER_TYPES" Width="1.5" PointX="17" PointY="44.75" />
+ <EntityTypeShape EntityType="RemoteModel.DISPENSER" Width="1.5" PointX="19.25" PointY="44.25" />
+ <EntityTypeShape EntityType="RemoteModel.EMBEDDED_FIRMWARE_VERSIONS" Width="1.5" PointX="6.75" PointY="36.625" />
+ <EntityTypeShape EntityType="RemoteModel.EVENT_TYPES" Width="1.5" PointX="14.25" PointY="13.625" />
+ <EntityTypeShape EntityType="RemoteModel.FIBER_SHAPES" Width="1.5" PointX="0.75" PointY="35" />
+ <EntityTypeShape EntityType="RemoteModel.FIBER_SYNTHS" Width="1.5" PointX="0.75" PointY="15" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_BLOWER_TYPES" Width="1.5" PointX="11.75" PointY="47" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_BLOWERS" Width="1.5" PointX="14" PointY="30.625" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_BREAK_SENSOR_TYPES" Width="1.5" PointX="11.75" PointY="51" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_BREAK_SENSORS" Width="1.5" PointX="14" PointY="34.75" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_DANCER_TYPES" Width="1.5" PointX="6.75" PointY="15" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_DANCERS" Width="1.5" PointX="9" PointY="26" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_MOTOR_TYPES" Width="1.5" PointX="14.75" PointY="39" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_MOTORS" Width="1.5" PointX="17" PointY="33.75" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_PID_CONTROL_TYPES" Width="1.5" PointX="9.75" PointY="42" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_PID_CONTROLS" Width="1.5" PointX="12" PointY="39.125" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_SPEED_SENSOR_TYPES" Width="1.5" PointX="6.75" PointY="43" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_SPEED_SENSORS" Width="1.5" PointX="9" PointY="37.75" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_VERSIONS" Width="1.5" PointX="6.75" PointY="29.5" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_WINDER_TYPES" Width="1.5" PointX="17.75" PointY="49" />
+ <EntityTypeShape EntityType="RemoteModel.HARDWARE_WINDERS" Width="1.5" PointX="20" PointY="32.875" />
+ <EntityTypeShape EntityType="RemoteModel.IDS_PACK_FORMULAS" Width="1.5" PointX="19.25" PointY="36.875" />
+ <EntityTypeShape EntityType="RemoteModel.IDS_PACKS" Width="1.5" PointX="21.5" PointY="23.125" />
+ <EntityTypeShape EntityType="RemoteModel.JOB_RUNS" Width="1.5" PointX="3.75" PointY="0.75" />
+ <EntityTypeShape EntityType="RemoteModel.JOB" Width="1.5" PointX="13.5" PointY="18.625" />
+ <EntityTypeShape EntityType="RemoteModel.LINEAR_MASS_DENSITY_UNITS" Width="1.5" PointX="0.75" PointY="22.5" />
+ <EntityTypeShape EntityType="RemoteModel.LIQUID_TYPES" Width="1.5" PointX="14.25" PointY="8.375" />
+ <EntityTypeShape EntityType="RemoteModel.LIQUID_TYPES_RMLS" Width="1.5" PointX="8.25" PointY="22.25" />
+ <EntityTypeShape EntityType="RemoteModel.MACHINE_STUDIO_VERSIONS" Width="1.5" PointX="13.5" PointY="58.25" />
+ <EntityTypeShape EntityType="RemoteModel.MACHINE_VERSIONS" Width="1.5" PointX="9" PointY="10.5" />
+ <EntityTypeShape EntityType="RemoteModel.MACHINE" Width="1.5" PointX="11.25" PointY="19" />
+ <EntityTypeShape EntityType="RemoteModel.MACHINES_EVENTS" Width="1.5" PointX="16.5" PointY="16.875" />
+ <EntityTypeShape EntityType="RemoteModel.MEDIA_CONDITIONS" Width="1.5" PointX="0.75" PointY="29.125" />
+ <EntityTypeShape EntityType="RemoteModel.MEDIA_MATERIALS" Width="1.5" PointX="0.75" PointY="18" />
+ <EntityTypeShape EntityType="RemoteModel.MEDIA_PURPOSES" Width="1.5" PointX="0.75" PointY="32.125" />
+ <EntityTypeShape EntityType="RemoteModel.MID_TANK_TYPES" Width="1.5" PointX="19.25" PointY="15.875" />
+ <EntityTypeShape EntityType="RemoteModel.ORGANIZATION" Width="1.5" PointX="0.75" PointY="9" />
+ <EntityTypeShape EntityType="RemoteModel.PERMISSION" Width="1.5" PointX="17.25" PointY="56.5" />
+ <EntityTypeShape EntityType="RemoteModel.PROCESS_PARAMETERS_TABLES" Width="1.5" PointX="7.5" PointY="56" />
+ <EntityTypeShape EntityType="RemoteModel.PROCESS_PARAMETERS_TABLES_GROUPS" Width="1.5" PointX="5.25" PointY="57.625" />
+ <EntityTypeShape EntityType="RemoteModel.RML" Width="1.5" PointX="3" PointY="19" />
+ <EntityTypeShape EntityType="RemoteModel.ROLE" Width="1.5" PointX="17.25" PointY="52.5" />
+ <EntityTypeShape EntityType="RemoteModel.ROLES_PERMISSIONS" Width="1.5" PointX="19.5" PointY="52.5" />
+ <EntityTypeShape EntityType="RemoteModel.SEGMENT" Width="1.5" PointX="15.75" PointY="26.25" />
+ <EntityTypeShape EntityType="RemoteModel.SITE" Width="1.5" PointX="3" PointY="9.25" />
+ <EntityTypeShape EntityType="RemoteModel.SITES_CATALOGS" Width="1.5" PointX="16.25" PointY="30.625" />
+ <EntityTypeShape EntityType="RemoteModel.SITES_RMLS" Width="1.5" PointX="5.25" PointY="18.375" />
+ <EntityTypeShape EntityType="RemoteModel.SPOOL_TYPES" Width="1.5" PointX="9" PointY="13.75" />
+ <EntityTypeShape EntityType="RemoteModel.SPOOL" Width="1.5" PointX="19.5" PointY="19" />
+ <EntityTypeShape EntityType="RemoteModel.sysdiagram" Width="1.5" PointX="3.75" PointY="4.75" />
+ <EntityTypeShape EntityType="RemoteModel.TANGO_UPDATES" Width="1.5" PointX="5.75" PointY="0.75" />
+ <EntityTypeShape EntityType="RemoteModel.TANGO_VERSIONS" Width="1.5" PointX="21.5" PointY="14.125" />
+ <EntityTypeShape EntityType="RemoteModel.TECH_CONTROLLERS" Width="1.5" PointX="5.75" PointY="5.75" />
+ <EntityTypeShape EntityType="RemoteModel.TECH_DISPENSERS" Width="1.5" PointX="7.75" PointY="0.75" />
+ <EntityTypeShape EntityType="RemoteModel.TECH_HEATERS" Width="1.5" PointX="7.75" PointY="3.75" />
+ <EntityTypeShape EntityType="RemoteModel.TECH_IOS" Width="1.5" PointX="9.75" PointY="0.75" />
+ <EntityTypeShape EntityType="RemoteModel.TECH_MONITORS" Width="1.5" PointX="9.75" PointY="5.75" />
+ <EntityTypeShape EntityType="RemoteModel.TECH_VALVES" Width="1.5" PointX="5.75" PointY="9.75" />
+ <EntityTypeShape EntityType="RemoteModel.USER" Width="1.5" PointX="11.25" PointY="32.375" />
+ <EntityTypeShape EntityType="RemoteModel.USERS_ROLES" Width="1.5" PointX="19.5" PointY="40.5" />
+ <EntityTypeShape EntityType="RemoteModel.WINDING_METHODS" Width="1.5" PointX="11.25" PointY="15.125" />
<AssociationConnector Association="RemoteModel.FK_ACTION_LOGS_USERS" />
<AssociationConnector Association="RemoteModel.FK_ORGANIZATIONS_ADDRESSES" />
<AssociationConnector Association="RemoteModel.FK_USERS_ADDRESSES" />
@@ -100,6 +100,7 @@
<AssociationConnector Association="RemoteModel.FK_RMLS_CCTS" />
<AssociationConnector Association="RemoteModel.FK_COLOR_CATALOGS_GROUPS_COLOR_CATALOGS" />
<AssociationConnector Association="RemoteModel.FK_JOBS_COLOR_CATALOGS" />
+ <AssociationConnector Association="RemoteModel.FK_SITES_CATALOGS_COLOR_CATALOGS" />
<AssociationConnector Association="RemoteModel.FK_COLOR_CATALOGS_ITEMS_COLOR_CATALOGS_GROUPS" />
<AssociationConnector Association="RemoteModel.FK_COLOR_CATALOGS_ITEMS_RECIPES_COLOR_CATALOGS_ITEMS" />
<AssociationConnector Association="RemoteModel.FK_COLOR_CATALOGS_ITEMS_RECIPES_RMLS" />
@@ -156,12 +157,16 @@
<AssociationConnector Association="RemoteModel.FK_RML_MEDIA_CONDITIONS" />
<AssociationConnector Association="RemoteModel.FK_RML_MEDIA_MATERIALS" />
<AssociationConnector Association="RemoteModel.FK_RML_MEDIA_PURPOSES" />
+ <AssociationConnector Association="RemoteModel.FK_SITES_ORGANIZATIONS" />
<AssociationConnector Association="RemoteModel.FK_USERS_ORGANIZATIONS" />
<AssociationConnector Association="RemoteModel.FK_ROLES_PERMISSIONS_PERMISSIONS" />
<AssociationConnector Association="RemoteModel.FK_PROCESS_PARAMETERS_TABLES_PROCESS_PARAMETERS_TABLES_GROUPS" />
<AssociationConnector Association="RemoteModel.FK_PROCESS_PARAMETERS_TABLES_GROUPS_RMLS" />
+ <AssociationConnector Association="RemoteModel.FK_SITES_RMLS_RMLS" />
<AssociationConnector Association="RemoteModel.FK_ROLES_PERMISSIONS_ROLES" />
<AssociationConnector Association="RemoteModel.FK_USERS_ROLES_ROLES" />
+ <AssociationConnector Association="RemoteModel.FK_SITES_CATALOGS_SITES" />
+ <AssociationConnector Association="RemoteModel.FK_SITES_RMLS_SITES" />
<AssociationConnector Association="RemoteModel.FK_SPOOLS_SPOOL_TYPES" />
<AssociationConnector Association="RemoteModel.FK_TANGO_VERSIONS_USERS" />
<AssociationConnector Association="RemoteModel.FK_USERS_ROLES_USERS" />
diff --git a/Software/Visual_Studio/Tango.DAL.Remote/DB/SITE.cs b/Software/Visual_Studio/Tango.DAL.Remote/DB/SITE.cs
index 10dcaef11..c0aa38e97 100644
--- a/Software/Visual_Studio/Tango.DAL.Remote/DB/SITE.cs
+++ b/Software/Visual_Studio/Tango.DAL.Remote/DB/SITE.cs
@@ -14,11 +14,24 @@ namespace Tango.DAL.Remote.DB
public partial class SITE
{
+ [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2214:DoNotCallOverridableMethodsInConstructors")]
+ public SITE()
+ {
+ this.SITES_CATALOGS = new HashSet<SITES_CATALOGS>();
+ this.SITES_RMLS = new HashSet<SITES_RMLS>();
+ }
+
public int ID { get; set; }
public string GUID { get; set; }
public System.DateTime LAST_UPDATED { get; set; }
public string ORGANIZATION_GUID { get; set; }
public string NAME { get; set; }
public string DESCRIPTION { get; set; }
+
+ public virtual ORGANIZATION ORGANIZATION { get; set; }
+ [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly")]
+ public virtual ICollection<SITES_CATALOGS> SITES_CATALOGS { get; set; }
+ [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Usage", "CA2227:CollectionPropertiesShouldBeReadOnly")]
+ public virtual ICollection<SITES_RMLS> SITES_RMLS { get; set; }
}
}
diff --git a/Software/Visual_Studio/Tango.DAL.Remote/DB/SITES_CATALOGS.cs b/Software/Visual_Studio/Tango.DAL.Remote/DB/SITES_CATALOGS.cs
index df712045c..4868cf35a 100644
--- a/Software/Visual_Studio/Tango.DAL.Remote/DB/SITES_CATALOGS.cs
+++ b/Software/Visual_Studio/Tango.DAL.Remote/DB/SITES_CATALOGS.cs
@@ -18,6 +18,9 @@ namespace Tango.DAL.Remote.DB
public string GUID { get; set; }
public System.DateTime LAST_UPDATED { get; set; }
public string SITE_GUID { get; set; }
- public string CATALOG_GUID { get; set; }
+ public string COLOR_CATALOG_GUID { get; set; }
+
+ public virtual COLOR_CATALOGS COLOR_CATALOGS { get; set; }
+ public virtual SITE SITE { get; set; }
}
}
diff --git a/Software/Visual_Studio/Tango.DAL.Remote/DB/SITES_RMLS.cs b/Software/Visual_Studio/Tango.DAL.Remote/DB/SITES_RMLS.cs
index ea22adbf8..945dd8bf9 100644
--- a/Software/Visual_Studio/Tango.DAL.Remote/DB/SITES_RMLS.cs
+++ b/Software/Visual_Studio/Tango.DAL.Remote/DB/SITES_RMLS.cs
@@ -19,5 +19,8 @@ namespace Tango.DAL.Remote.DB
public System.DateTime LAST_UPDATED { get; set; }
public string SITE_GUID { get; set; }
public string RML_GUID { get; set; }
+
+ public virtual RML RML { get; set; }
+ public virtual SITE SITE { get; set; }
}
}
diff --git a/Software/Visual_Studio/Tango.SQLExaminer/SQLExaminer/Configurations/ProvisionMachine.xml b/Software/Visual_Studio/Tango.SQLExaminer/SQLExaminer/Configurations/ProvisionMachine.xml
index 3f61fe617..a2221c619 100644
--- a/Software/Visual_Studio/Tango.SQLExaminer/SQLExaminer/Configurations/ProvisionMachine.xml
+++ b/Software/Visual_Studio/Tango.SQLExaminer/SQLExaminer/Configurations/ProvisionMachine.xml
Binary files differ
diff --git a/Software/Visual_Studio/Tango.SQLExaminer/SQLExaminer/Configurations/UpdateMachine.xml b/Software/Visual_Studio/Tango.SQLExaminer/SQLExaminer/Configurations/UpdateMachine.xml
index 97dad3717..8812256d5 100644
--- a/Software/Visual_Studio/Tango.SQLExaminer/SQLExaminer/Configurations/UpdateMachine.xml
+++ b/Software/Visual_Studio/Tango.SQLExaminer/SQLExaminer/Configurations/UpdateMachine.xml
Binary files differ
diff --git a/Software/Visual_Studio/Tango.BL/Entities/SitesCatalogBase.cs b/Software/Visual_Studio/Tango.BL/Entities/SitesCatalogBase.cs
index 85175d6ad..15f7ef6df 100644
--- a/Software/Visual_Studio/Tango.BL/Entities/SitesCatalogBase.cs
+++ b/Software/Visual_Studio/Tango.BL/Entities/SitesCatalogBase.cs
@@ -26,6 +26,10 @@ namespace Tango.BL.Entities
public abstract class SitesCatalogBase : ObservableEntity<SitesCatalog>
{
+ public event EventHandler<ColorCatalog> ColorCatalogChanged;
+
+ public event EventHandler<Site> SiteChanged;
+
protected String _siteguid;
/// <summary>
@@ -33,6 +37,7 @@ namespace Tango.BL.Entities
/// </summary>
[Column("SITE_GUID")]
+ [ForeignKey("Site")]
public String SiteGuid
{
@@ -51,32 +56,115 @@ namespace Tango.BL.Entities
}
}
- protected String _catalogguid;
+ protected String _colorcatalogguid;
/// <summary>
/// Gets or sets the sitescatalogbase catalog guid.
/// </summary>
- [Column("CATALOG_GUID")]
+ [Column("COLOR_CATALOG_GUID")]
+ [ForeignKey("ColorCatalog")]
+
+ public String ColorCatalogGuid
+ {
+ get
+ {
+ return _colorcatalogguid;
+ }
+
+ set
+ {
+ if (_colorcatalogguid != value)
+ {
+ _colorcatalogguid = value;
+
+ }
+ }
+ }
+
+ protected ColorCatalog _colorcatalog;
+
+ /// <summary>
+ /// Gets or sets the sitescatalogbase color catalogs.
+ /// </summary>
+
+ [XmlIgnore]
+ [JsonIgnore]
+ public virtual ColorCatalog ColorCatalog
+ {
+ get
+ {
+ return _colorcatalog;
+ }
+
+ set
+ {
+ if (_colorcatalog != value)
+ {
+ _colorcatalog = value;
+
+ if (ColorCatalog != null)
+ {
+ ColorCatalogGuid = ColorCatalog.Guid;
+ }
+
+ OnColorCatalogChanged(value);
+
+ }
+ }
+ }
+
+ protected Site _site;
+
+ /// <summary>
+ /// Gets or sets the sitescatalogbase site.
+ /// </summary>
- public String CatalogGuid
+ [XmlIgnore]
+ [JsonIgnore]
+ public virtual Site Site
{
get
{
- return _catalogguid;
+ return _site;
}
set
{
- if (_catalogguid != value)
+ if (_site != value)
{
- _catalogguid = value;
+ _site = value;
+
+ if (Site != null)
+ {
+ SiteGuid = Site.Guid;
+ }
+
+ OnSiteChanged(value);
}
}
}
/// <summary>
+ /// Called when the ColorCatalog has changed.
+ /// </summary>
+ protected virtual void OnColorCatalogChanged(ColorCatalog colorcatalog)
+ {
+ ColorCatalogChanged?.Invoke(this, colorcatalog);
+ RaisePropertyChanged(nameof(ColorCatalog));
+ }
+
+ /// <summary>
+ /// Called when the Site has changed.
+ /// </summary>
+ protected virtual void OnSiteChanged(Site site)
+ {
+ SiteChanged?.Invoke(this, site);
+ RaisePropertyChanged(nameof(Site));
+ }
+
+ /// <summary>
/// Initializes a new instance of the <see cref="SitesCatalogBase" /> class.
/// </summary>
public SitesCatalogBase() : base()
@@ -51,32 +56,115 @@ namespace Tango.BL.Entities
/// <summary>
- /// Gets or sets the sitescatalogbase catalog guid.
+ /// Gets or sets the sitescatalogbase color catalog guid.
/// </summary>